/*
 * log.h - message logging
 *
 */

#ifndef LOG_H_
#define LOG_H_

typedef enum {
	LOG_LEVEL_ERROR,
	LOG_LEVEL_WARN,
	LOG_LEVEL_INFO,
	LOG_LEVEL_VERBOSE,
	LOG_LEVEL_DEBUG,
} log_level_t;

typedef enum {
	LOG_FACILITY_DAEMON,
	LOG_FACILITY_LOCAL0,
	LOG_FACILITY_LOCAL1,
	LOG_FACILITY_LOCAL2,
	LOG_FACILITY_LOCAL3,
	LOG_FACILITY_LOCAL4,
	LOG_FACILITY_LOCAL5,
	LOG_FACILITY_LOCAL6,
	LOG_FACILITY_LOCAL7,
	LOG_FACILITY_SYSLOG,
	LOG_FACILITY_USER,
} log_facility_t;

typedef void (*error_handler_t)(int code);

/* set error callback */
void set_error_hanlder(error_handler_t handler);

/* log_init - initialize logger
 *
 * argv0: argv[0] pointer
 * level: logging level
 * to_syslog: send messages to syslog instead stderr
 * facility: syslog facility to use
 * opt_time_format: strftime format string or NULL
 */
void log_init(char *argv0, log_level_t level, int to_syslog, int facility, char *opt_time_format);

/* print message corresponding to logging level */
void debug(const char *fmt, ...) __attribute__((format(printf,1,2)));
void verbose(const char *fmt, ...) __attribute__((format(printf,1,2)));
void info(const char *fmt, ...) __attribute__((format(printf,1,2)));
void warn(const char *fmt, ...) __attribute__((format(printf,1,2)));

/* print message and exit returning -1 */
void error(const char *fmt, ...) __attribute__((format(printf,1,2)));

/* print message and exit with code */
void error_exit(int code, const char *fmt, ...) __attribute__((format(printf,2,3)));

#endif
